==> qt-creator-opensource-src-4.0.1.tar.gz: qt-creator-opensource-src-4.0.1/src/plugins/texteditor/codeassist/codeassistant.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef CODEASSISTANT_H
#define CODEASSISTANT_H

#include "assistenums.h"

#include <texteditor/texteditor_global.h>

#include <QObject>

namespace TextEditor {

class CodeAssistantPrivate;
class CompletionSettings;
class IAssistProvider;
class TextEditorWidget;

class CodeAssistant : public QObject
{
    Q_OBJECT

public:
    CodeAssistant();
    ~CodeAssistant();

    void configure(TextEditorWidget *editorWidget);
    void updateFromCompletionSettings(const TextEditor::CompletionSettings &settings);

    void process();
    void notifyChange();
    bool hasContext() const;
    void destroyContext();

    void invoke(AssistKind assistKind, IAssistProvider *provider = 0);

signals:
    void finished();

private:
    CodeAssistantPrivate *d;
};

} //TextEditor

#endif // CODEASSISTANT_H

==> qt-creator-opensource-src-4.1.0.tar.gz: qt-creator-opensource-src-4.1.0/src/plugins/texteditor/codeassist/codeassistant.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "assistenums.h"

#include <texteditor/texteditor_global.h>

#include <QObject>

namespace TextEditor {

class CodeAssistantPrivate;
class CompletionSettings;
class IAssistProvider;
class TextEditorWidget;

class CodeAssistant : public QObject
{
    Q_OBJECT

public:
    CodeAssistant();
    ~CodeAssistant();

    void configure(TextEditorWidget *editorWidget);

    void process();
    void notifyChange();
    bool hasContext() const;
    void destroyContext();

    void invoke(AssistKind assistKind, IAssistProvider *provider = 0);

signals:
    void finished();

private:
    CodeAssistantPrivate *d;
};

} //TextEditor
